Startup views
-------------

Startup views are views requiring no context, from which you usually start
browsing (for instance the index page). The usual selectors are
:class:`~cubicweb.predicates.none_rset` or :class:`~logilab.common.registry.yes`.

You'll find here a description of startup views provided by the framework.

.. automodule:: cubicweb.web.views.startup


Other startup views:

*schema*
    A view dedicated to the display of the schema of the instance

.. XXX to be continued